@@ -86,7 +86,7 @@ def test_composition_energy_adjustment():
 def test_temp_energy_adjustment():
     ea = TemperatureEnergyAdjustment(-0.1, 298, 5, uncertainty_per_deg=0, name="entropy")
     assert ea.name == "entropy"
-    assert ea.value == -0.1 * 298 * 5
+    assert ea.value == approx(-0.1 * 298 * 5)
     assert ea.n_atoms == 5
     assert ea.temp == 298
     assert ea.explain == "Temperature-based energy adjustment (-0.1000 eV/K/atom x 298 K x 5 atoms)"
@@ -470,11 +470,13 @@ class TestGibbsComputedStructureEntry(TestCase):
             for temp in self.temps
         }
 
-        with open(f"{TEST_DIR}/Mn-O_entries.json") as file:
+        with open(f"{TEST_DIR}/Mn-O_entries.json", encoding="utf-8") as file:
             data = json.load(file)
-        with open(f"{TEST_DIR}/structure_CO2.json") as file:
+        with open(f"{TEST_DIR}/structure_CO2.json", encoding="utf-8") as file:
             self.co2_struct = MontyDecoder().process_decoded(json.load(file))
 
+        with open(f"{TEST_DIR}/Mn-O_entries.json") as file:
+            data = json.load(file)
         self.mp_entries = [MontyDecoder().process_decoded(d) for d in data]
 
     def test_gf_sisso(self):
