@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import json
-import unittest
+from unittest import TestCase
 
 from monty.json import MontyDecoder
 from pytest import approx
@@ -10,9 +10,9 @@ from pymatgen.entries.exp_entries import ExpEntry
 from pymatgen.util.testing import TEST_FILES_DIR
 
 
-class TestExpEntry(unittest.TestCase):
+class TestExpEntry(TestCase):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/Fe2O3_exp.json") as file:
+        with open(f"{TEST_FILES_DIR}/entries/Fe2O3_exp.json", encoding="utf-8") as file:
             thermo_data = json.load(file, cls=MontyDecoder)
         self.entry = ExpEntry("Fe2O3", thermo_data)
 
