@@ -1,9 +1,11 @@
 from __future__ import annotations
 
 import os.path
+import tarfile
 from collections import defaultdict
 
 import pytest
+from monty.tempfile import ScratchDir
 from pytest import approx
 
 from pymatgen.io.abinit.pseudos import Pseudo, PseudoTable
@@ -18,6 +20,7 @@ class TestPseudo(PymatgenTest):
         nc_pseudo_fnames["Si"] = [f"{TEST_DIR}/{file}" for file in ("14si.pspnc", "14si.4.hgh", "14-Si.LDA.fhi")]
 
         self.nc_pseudos = defaultdict(list)
+        self.paw_pseudos = defaultdict(list)
 
         for symbol, file_names in nc_pseudo_fnames.items():
             for file_name in file_names:
@@ -91,6 +94,39 @@ class TestPseudo(PymatgenTest):
         # Test pickle
         self.serialize_with_pickle(table, test_eq=False)
 
+    def test_paw_pseudos(self):
+        """Test 28ni.paw."""
+        file_name = f"{TEST_DIR}/28ni.paw.tar.xz"
+        symbol = "Ni"
+        with ScratchDir(".") as tmp_dir, tarfile.open(file_name, mode="r:xz") as t:
+            # TODO: remove attr check after only 3.12+
+            if hasattr(tarfile, "data_filter"):
+                t.extractall(tmp_dir, filter="data")
+            else:
+                t.extractall(tmp_dir)  # noqa: S202
+            path = os.path.join(tmp_dir, "28ni.paw")
+            pseudo = Pseudo.from_file(path)
+
+            assert repr(pseudo)
+            assert str(pseudo)
+            assert not pseudo.isnc
+            assert pseudo.ispaw
+            assert pseudo.Z == 28
+            assert pseudo.symbol == symbol
+            assert pseudo.Z_val == 18
+            assert pseudo.paw_radius >= 0.0
+
+            assert pseudo.l_max == 2
+            assert pseudo.l_local == 0
+            assert pseudo.supports_soc
+            assert pseudo.md5 is not None
+
+            # Test pickle
+            self.serialize_with_pickle(pseudo)
+
+            # Test MSONable
+            self.assert_msonable(pseudo)
+
     def test_pawxml_pseudos(self):
         """Test O.GGA_PBE-JTH-paw.xml."""
         oxygen = Pseudo.from_file(f"{TEST_DIR}/O.GGA_PBE-JTH-paw.xml")
@@ -129,8 +165,8 @@ class TestPseudo(PymatgenTest):
         ger.as_tmpfile()
 
         assert ger.symbol == "Ge"
-        assert ger.Z == 32.0
-        assert ger.Z_val == 4.0
+        assert ger.Z == approx(32.0)  # noqa: SIM300
+        assert ger.Z_val == approx(4.0)
         assert ger.isnc
         assert not ger.ispaw
         assert ger.l_max == 2
@@ -153,8 +189,8 @@ class TestPseudo(PymatgenTest):
         self.assert_msonable(pb)
 
         assert pb.symbol == "Pb"
-        assert pb.Z == 82.0
-        assert pb.Z_val == 14.0
+        assert pb.Z == approx(82.0)  # noqa: SIM300
+        assert pb.Z_val == approx(14.0)
         assert pb.isnc
         assert not pb.ispaw
         assert pb.l_max == 2
