@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import logging
 import os
 
 import pytest
@@ -11,6 +10,8 @@ from pymatgen.io.qchem.inputs import QCInput
 from pymatgen.io.qchem.sets import OptSet
 from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
 
+TEST_DIR = f"{TEST_FILES_DIR}/io/qchem"
+
 __author__ = "Brandon Wood, Samuel Blau, Shyam Dwaraknath, Julian Self, Evan Spotte-Smith, Ryan Kingsbury"
 __copyright__ = "Copyright 2018-2022, The Materials Project"
 __version__ = "0.1"
@@ -18,14 +19,8 @@ __maintainer__ = "Samuel Blau"
 __email__ = "samblau1@gmail.com"
 __credits__ = "Xiaohui Qu"
 
-module_dir = os.path.dirname(os.path.abspath(__file__))
-logger = logging.getLogger(__name__)
-
 
 class TestQCInput(PymatgenTest):
-    # ef setUpClass(cls):
-    # add things that show up over and over again
-
     def test_molecule_template(self):
         species = ["C", "O"]
         coords = [
@@ -43,7 +38,6 @@ $end"""
         assert molecule_actual == molecule_test
 
     def test_multi_molecule_template(self):
-        self.maxDiff = None
         species = ["C", "C", "H", "H", "H", "H"]
         coords_1 = [
             [0.000000, 0.000000, 0.000000],
@@ -220,7 +214,10 @@ $end"""
 $end"""
         assert scan_test == scan_actual
 
-        bad_scan = {"stre": ["1 2 1.0 2.0 0.05", "3 4 1.5 2.0 0.05"], "bend": ["7 8 9 90 120 10"]}
+        bad_scan = {
+            "stre": ["1 2 1.0 2.0 0.05", "3 4 1.5 2.0 0.05"],
+            "bend": ["7 8 9 90 120 10"],
+        }
         with pytest.raises(ValueError, match="Q-Chem only supports PES_SCAN with two or less variables"):
             QCInput.scan_template(bad_scan)
 
@@ -248,12 +245,36 @@ $end"""
     def test_cdft_template(self):
         cdft = [
             [
-                {"value": 1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["c"]},
-                {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["s"]},
+                {
+                    "value": 1.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["c"],
+                },
+                {
+                    "value": 0.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["s"],
+                },
             ],
             [
-                {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["c"]},
-                {"value": -1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["s"]},
+                {
+                    "value": 0.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["c"],
+                },
+                {
+                    "value": -1.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["s"],
+                },
             ],
         ]
 
@@ -741,7 +762,7 @@ $end
             assert i_str in multi_job_str_test
 
     def test_from_multi_jobs_file(self):
-        job_list_test = QCInput.from_multi_jobs_file(f"{TEST_FILES_DIR}/qchem/pt_n2_wb97mv_0.0.in")
+        job_list_test = QCInput.from_multi_jobs_file(f"{TEST_DIR}/pt_n2_wb97mv_0.0.in")
         species = [
             "S",
             "C",
@@ -930,7 +951,11 @@ $scan
    bend 3 4 5 60 90 5
 $end"""
         scan_test = QCInput.read_scan(str_scan)
-        scan_actual = {"stre": ["1 2 1.1 1.4 0.03"], "bend": ["3 4 5 60 90 5"], "tors": []}
+        scan_actual = {
+            "stre": ["1 2 1.1 1.4 0.03"],
+            "bend": ["3 4 5 60 90 5"],
+            "tors": [],
+        }
 
         assert scan_test == scan_actual
 
@@ -953,7 +978,10 @@ $scan
    tors 6 7 8 9 -180 180 30
 $end"""
 
-        with pytest.raises(ValueError, match="No more than two variables are allows in the scan section"):
+        with pytest.raises(
+            ValueError,
+            match="No more than two variables are allows in the scan section",
+        ):
             QCInput.read_scan(str_scan_2)
 
     def test_read_negative(self):
@@ -1143,12 +1171,36 @@ $end
 
         result = [
             [
-                {"value": 1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": [None]},
-                {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["s"]},
+                {
+                    "value": 1.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": [None],
+                },
+                {
+                    "value": 0.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["s"],
+                },
             ],
             [
-                {"value": 0.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": [None]},
-                {"value": -1.0, "coefficients": [1.0], "first_atoms": [1], "last_atoms": [27], "types": ["s"]},
+                {
+                    "value": 0.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": [None],
+                },
+                {
+                    "value": -1.0,
+                    "coefficients": [1.0],
+                    "first_atoms": [1],
+                    "last_atoms": [27],
+                    "types": ["s"],
+                },
             ],
         ]
 
@@ -1174,68 +1226,68 @@ $end"""
         assert QCInput.read_almo(str_almo) == result
 
     def test_write_file_from_opt_set(self):
-        odd_dict = loadfn(f"{module_dir}/odd.json")
+        odd_dict = loadfn(f"{TEST_DIR}/odd.json")
         odd_mol = odd_dict["spec"]["_tasks"][0]["molecule"]
         qcinp = OptSet(odd_mol)
-        qcinp.write_file(f"{module_dir}/test.qin")
-        test_path = f"{module_dir}/test.qin"
-        ref_path = f"{module_dir}/test_ref.qin"
+        qcinp.write_file(f"{TEST_DIR}/test.qin")
+        test_path = f"{TEST_DIR}/test.qin"
+        ref_path = f"{TEST_DIR}/test_ref.qin"
 
-        with open(ref_path) as ref_file, open(test_path) as test_file:
-            for l_test, l_ref in zip(test_file, ref_file):
+        with open(ref_path, encoding="utf-8") as ref_file, open(test_path, encoding="utf-8") as test_file:
+            for l_test, l_ref in zip(test_file, ref_file, strict=True):
                 # By default, if this statement fails the offending line will be printed
                 assert l_test == l_ref
 
-        os.remove(f"{module_dir}/test.qin")
+        os.remove(f"{TEST_DIR}/test.qin")
 
     def test_write_file_from_opt_set_with_vdw(self):
-        odd_dict = loadfn(f"{module_dir}/odd.json")
+        odd_dict = loadfn(f"{TEST_DIR}/odd.json")
         odd_mol = odd_dict["spec"]["_tasks"][0]["molecule"]
         qcinp = OptSet(odd_mol, overwrite_inputs={"van_der_waals": {"16": 3.14159}})
-        qcinp.write_file(f"{module_dir}/test_vdw.qin")
-        test_path = f"{module_dir}/test_vdw.qin"
-        ref_path = f"{module_dir}/test_ref_vdw.qin"
+        qcinp.write_file(f"{TEST_DIR}/test_vdw.qin")
+        test_path = f"{TEST_DIR}/test_vdw.qin"
+        ref_path = f"{TEST_DIR}/test_ref_vdw.qin"
 
-        with open(ref_path) as ref_file, open(test_path) as test_file:
-            for l_test, l_ref in zip(test_file, ref_file):
+        with open(ref_path, encoding="utf-8") as ref_file, open(test_path, encoding="utf-8") as test_file:
+            for l_test, l_ref in zip(test_file, ref_file, strict=True):
                 # By default, if this statement fails the offending line will be printed
                 assert l_test == l_ref
 
-        os.remove(f"{module_dir}/test_vdw.qin")
+        os.remove(f"{TEST_DIR}/test_vdw.qin")
 
     def test_read_write_nbo7(self):
-        test_path = f"{module_dir}/test_nbo7.qin"
-        ref_path = f"{TEST_FILES_DIR}/molecules/new_qchem_files/nbo7.qin"
-        qcinp = QCInput.from_file(f"{TEST_FILES_DIR}/molecules/new_qchem_files/nbo7.qin")
+        test_path = f"{TEST_DIR}/test_nbo7.qin"
+        ref_path = f"{TEST_DIR}/new_qchem_files/nbo7.qin"
+        qcinp = QCInput.from_file(f"{TEST_DIR}/new_qchem_files/nbo7.qin")
         qcinp.write_file(test_path)
 
-        with open(test_path) as ref_file, open(ref_path) as test_file:
-            for l_test, l_ref in zip(test_file, ref_file):
+        with open(test_path, encoding="utf-8") as ref_file, open(ref_path, encoding="utf-8") as test_file:
+            for l_test, l_ref in zip(test_file, ref_file, strict=True):
                 # By default, if this statement fails the offending line will be printed
                 assert l_test == l_ref
 
         os.remove(test_path)
 
     def test_read_write_nbo_e2pert(self):
-        qcinp = QCInput.from_file(f"{TEST_FILES_DIR}/molecules/new_qchem_files/e2pert.qin")
-        qcinp.write_file(f"{module_dir}/test_e2pert.qin")
-        test_path = f"{TEST_FILES_DIR}/molecules/new_qchem_files/e2pert.qin"
-        ref_path = f"{module_dir}/test_e2pert.qin"
+        qcinp = QCInput.from_file(f"{TEST_DIR}/new_qchem_files/e2pert.qin")
+        qcinp.write_file(f"{TEST_DIR}/test_e2pert.qin")
+        test_path = f"{TEST_DIR}/new_qchem_files/e2pert.qin"
+        ref_path = f"{TEST_DIR}/test_e2pert.qin"
 
-        with open(ref_path) as ref_file, open(test_path) as test_file:
-            for l_test, l_ref in zip(test_file, ref_file):
+        with open(ref_path, encoding="utf-8") as ref_file, open(test_path, encoding="utf-8") as test_file:
+            for l_test, l_ref in zip(test_file, ref_file, strict=True):
                 assert l_test == l_ref
 
-        os.remove(f"{module_dir}/test_e2pert.qin")
+        os.remove(f"{TEST_DIR}/test_e2pert.qin")
 
     def test_read_write_custom_smd(self):
-        qcinp = QCInput.from_file(f"{TEST_FILES_DIR}/molecules/new_qchem_files/custom_smd.qin")
-        qcinp.write_file(f"{module_dir}/test_custom_smd.qin")
-        test_path = f"{TEST_FILES_DIR}/molecules/new_qchem_files/custom_smd.qin"
-        ref_path = f"{module_dir}/test_custom_smd.qin"
+        qcinp = QCInput.from_file(f"{TEST_DIR}/new_qchem_files/custom_smd.qin")
+        qcinp.write_file(f"{TEST_DIR}/test_custom_smd.qin")
+        test_path = f"{TEST_DIR}/new_qchem_files/custom_smd.qin"
+        ref_path = f"{TEST_DIR}/test_custom_smd.qin"
 
-        with open(ref_path) as ref_file, open(test_path) as test_file:
-            for l_test, l_ref in zip(test_file, ref_file):
+        with open(ref_path, encoding="utf-8") as ref_file, open(test_path, encoding="utf-8") as test_file:
+            for l_test, l_ref in zip(test_file, ref_file, strict=True):
                 assert l_test == l_ref
 
-        os.remove(f"{module_dir}/test_custom_smd.qin")
+        os.remove(f"{TEST_DIR}/test_custom_smd.qin")
