@@ -389,7 +389,7 @@ CELL_PARAMETERS angstrom
 
         assert_allclose(lattice, pw_in.structure.lattice.matrix)
         assert pw_in.sections["system"]["smearing"] == "cold"
-        assert pw_in.sections["electrons"]["conv_thr"] == 5.3e-5
+        assert pw_in.sections["electrons"]["conv_thr"] == approx(5.3e-5)
         assert pw_in.kpoints_mode == "automatic"
         assert pw_in.kpoints_grid == (4, 4, 4)
         assert pw_in.kpoints_shift == (1, 1, 1)
