@@ -30,7 +30,7 @@ class TestAirssProvider:
         assert grid == (6, 6, 8)
         assert offset == (0, 0, 0)
         assert nkpts == 144
-        assert spacing == 0.05
+        assert spacing == approx(0.05)
 
     def test_pspots(self, provider: AirssProvider):
         ps_pots = provider.get_pspots()
@@ -106,7 +106,13 @@ class TestAirssProvider:
     def test_as_dict(self, provider: AirssProvider):
         verbose_dict = provider.as_dict(verbose=True)
 
-        assert sorted(verbose_dict) == ["@class", "@module", "@version", "parse_rems", "res"]
+        assert sorted(verbose_dict) == [
+            "@class",
+            "@module",
+            "@version",
+            "parse_rems",
+            "res",
+        ]
 
         # test round-trip serialization/deserialization gives same dict
         assert AirssProvider.from_dict(verbose_dict).as_dict() == verbose_dict
@@ -142,7 +148,7 @@ class TestAirssProvider:
 
 class TestSpin:
     def test_read_spin(self):
-        with open(res_coc) as file:
+        with open(res_coc, encoding="utf-8") as file:
             lines = file.readlines()
         # add spin to a line
         lines[25] = f"{lines[25][:-1]} -1.4\n"
@@ -157,14 +163,20 @@ class TestSpin:
 
     def test_gh_2938_example(self):
         res_spin_file = f"{TEST_DIR}/spins-in-last-col.res"
-        with open(res_spin_file) as res_file:
+        with open(res_spin_file, encoding="utf-8") as res_file:
             contents = res_file.read()
 
         provider = AirssProvider.from_str(contents)
 
         for site in provider.structure:
             if site.properties["magmom"] is not None:
-                assert site.properties.get("magmom") in (3.31, 4.12, -0.01, -0.04, -0.17)
+                assert site.properties.get("magmom") in (
+                    3.31,
+                    4.12,
+                    -0.01,
+                    -0.04,
+                    -0.17,
+                )
 
 
 class TestStructureModule:
