@@ -11,7 +11,7 @@ from pymatgen.analysis.xas.spectrum import XAS
 from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
 from pymatgen.vis.plotters import SpectrumPlotter
 
-with open(f"{TEST_FILES_DIR}/analysis/spectrum_test/LiCoO2_k_xanes.json") as file:
+with open(f"{TEST_FILES_DIR}/analysis/spectrum_test/LiCoO2_k_xanes.json", encoding="utf-8") as file:
     spect_data_dict = json.load(file, cls=MontyDecoder)
 
 
@@ -23,7 +23,7 @@ class TestSpectrumPlotter(PymatgenTest):
         self.plotter = SpectrumPlotter(yshift=0.2)
         self.plotter.add_spectrum("LiCoO2", self.xanes)
         xanes = self.xanes.copy()
-        xanes.y += np.random.randn(len(xanes.y)) * 0.005
+        xanes.y += np.random.default_rng().standard_normal(len(xanes.y)) * 0.005
         self.plotter.add_spectrum("LiCoO2 + noise", xanes)
         self.plotter.add_spectrum("LiCoO2 - replot", xanes, "k")
         ax = self.plotter.get_plot()
@@ -36,7 +36,7 @@ class TestSpectrumPlotter(PymatgenTest):
         self.plotter = SpectrumPlotter(yshift=0.2, stack=True)
         self.plotter.add_spectrum("LiCoO2", self.xanes, "b")
         xanes = self.xanes.copy()
-        xanes.y += np.random.randn(len(xanes.y)) * 0.005
+        xanes.y += np.random.default_rng().standard_normal(len(xanes.y)) * 0.005
         self.plotter.add_spectrum("LiCoO2 + noise", xanes, "r")
         ax = self.plotter.get_plot()
         assert isinstance(ax, plt.Axes)
@@ -46,7 +46,7 @@ class TestSpectrumPlotter(PymatgenTest):
         # create spectra_dict
         spectra_dict = {"LiCoO2": self.xanes}
         xanes = self.xanes.copy()
-        xanes.y += np.random.randn(len(xanes.y)) * 0.005
+        xanes.y += np.random.default_rng().standard_normal(len(xanes.y)) * 0.005
         spectra_dict["LiCoO2 + noise"] = spectra_dict["LiCoO2 - replot"] = xanes
 
         self.plotter = SpectrumPlotter(yshift=0.2)
